# Generated by Django 3.2.23 on 2024-01-16 06:00

import django.core.validators
import django.db.models.deletion
import django_countries.fields
import djmoney.models.fields
from django.db import migrations, models

import django_pain.constants


class Migration(migrations.Migration):
    dependencies = [
        ("django_pain", "0039_vs_remove_year_default"),
    ]

    operations = [
        migrations.CreateModel(
            name="Invoice",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("uuid", models.UUIDField(unique=True)),
                ("app_id", models.TextField(verbose_name="Application ID")),
                ("name", models.TextField(blank=True, null=True, verbose_name="Name")),
                ("organization", models.TextField(blank=True, null=True, verbose_name="Organization")),
                ("street1", models.TextField(verbose_name="Street")),
                ("street2", models.TextField(blank=True, null=True, verbose_name="Street 2")),
                ("street3", models.TextField(blank=True, null=True, verbose_name="Street 3")),
                ("city", models.TextField(verbose_name="City")),
                ("state_or_province", models.TextField(blank=True, null=True, verbose_name="State or province")),
                ("postal_code", models.TextField(verbose_name="Postal code")),
                ("country_code", django_countries.fields.CountryField(max_length=2, verbose_name="Country")),
                (
                    "company_registration_number",
                    models.TextField(blank=True, null=True, verbose_name="Company registration number"),
                ),
                ("vat_number", models.TextField(blank=True, null=True, verbose_name="VAT number")),
                ("created_at", models.DateTimeField(auto_now_add=True, verbose_name="Create time")),
                ("tax_at", models.DateField(verbose_name="Tax point")),
                ("number", models.TextField(unique=True, verbose_name="Invoice number")),
                ("variable_symbol", models.TextField(blank=True, verbose_name="Variable symbol")),
                (
                    "price_total_base",
                    models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total base price"),
                ),
                ("price_total_vat", models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total VAT")),
                (
                    "price_total",
                    models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total price with VAT"),
                ),
                ("price_to_pay", models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Price to pay")),
                ("currency", djmoney.models.fields.CurrencyField(default="CZK", max_length=3)),
                ("file_uid", models.TextField(blank=True, null=True, verbose_name="PDF")),
                ("bank_account", models.TextField(verbose_name="Bank account")),
                (
                    "payment_type",
                    models.TextField(
                        choices=[
                            (django_pain.constants.PaymentType["TRANSFER"], "transfer"),
                            (django_pain.constants.PaymentType["CARD_PAYMENT"], "card payment"),
                        ],
                        verbose_name="Payment type",
                    ),
                ),
                ("payment_request_uuid", models.UUIDField(blank=True, null=True, verbose_name="Payment request")),
            ],
            options={
                "verbose_name": "Invoice",
                "verbose_name_plural": "Invoices",
            },
        ),
        migrations.CreateModel(
            name="InvoiceItem",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.TextField(verbose_name="Description")),
                ("vat_rate", models.DecimalField(decimal_places=4, max_digits=10, verbose_name="VAT rate")),
                (
                    "quantity",
                    models.IntegerField(
                        default=1, validators=[django.core.validators.MinValueValidator(1)], verbose_name="Quantity"
                    ),
                ),
                (
                    "price_per_unit",
                    models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Price per unit"),
                ),
                (
                    "price_total_base",
                    models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total base price"),
                ),
                ("price_total_vat", models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total VAT")),
                (
                    "price_total",
                    models.DecimalField(decimal_places=10, max_digits=64, verbose_name="Total price with VAT"),
                ),
            ],
        ),
        migrations.CreateModel(
            name="InvoiceNumberSequence",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("app_id", models.TextField(verbose_name="Application ID")),
                (
                    "year",
                    models.IntegerField(
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(9999),
                        ],
                        verbose_name="Year",
                    ),
                ),
                ("prefix", models.TextField(verbose_name="Prefix")),
                ("current_number", models.IntegerField(default=0, editable=False)),
            ],
        ),
        migrations.AddField(
            model_name="billingitemtype",
            name="not_invoiceable",
            field=models.BooleanField(default=False, verbose_name="Not invoiceable"),
        ),
        migrations.AddConstraint(
            model_name="invoicenumbersequence",
            constraint=models.CheckConstraint(
                check=models.Q(("year__gte", 1), ("year__lte", 9999)), name="invoice_year_range"
            ),
        ),
        migrations.AlterUniqueTogether(
            name="invoicenumbersequence",
            unique_together={("app_id", "year", "prefix")},
        ),
        migrations.AddField(
            model_name="invoiceitem",
            name="invoice",
            field=models.ForeignKey(
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="items",
                to="django_pain.invoice",
            ),
        ),
        migrations.AddField(
            model_name="invoice",
            name="customer",
            field=models.ForeignKey(
                editable=False,
                on_delete=django.db.models.deletion.RESTRICT,
                related_name="+",
                to="django_pain.customer",
            ),
        ),
    ]
